# Workflow Class

The Workflow class represents a computational workflow in DerivaML. Workflows define
the steps and logic for ML experiments and can be associated with Python scripts,
Jupyter notebooks, or programmatically defined processes.

::: deriva_ml.execution.workflow
    handler: python
